@@ -2,7 +2,7 @@ from ..style import Style
 
 
 class Rectangle:
-    def __init__(self, width: int, height: int, x: int = None, y: int = None, style: Style = None):
+    def __init__(self, width: int, height: int, x: int = 0, y: int = 0, style: Style = Style({"fill": "black"})):
         self.width = width
         self.height = height
         self.x = x
@@ -12,4 +12,3 @@ class Rectangle:
     def svg_content(self) -> str:
         content = f'<rect width="{self.width}" height="{self.height}" x={self.x} y={self.y} style={self.style.svg()} />'
         return content
-
